<?php
$translations = array(
	'General_Locale' => 'te_IN.UTF-8',
	'General_TranslatorName' => 'Veeven',
	'General_TranslatorEmail' => 'veeven@gmail.com',
	'General_EnglishLanguageName' => 'Telugu',
	'General_OriginalLanguageName' => 'తెలుగు',
	'General_HelloUser' => 'హలో, %s!',
	'General_Dashboard' => 'డాష్‌బోర్డు',
	'General_MultiSitesSummary' => 'అన్ని వెబ్‌సైట్లూ',
	'General_AllWebsitesDashboard' => 'అన్ని వెబ్‌సైట్లడాష్‌బోర్డు',
	'General_Widgets' => 'విడ్జెట్లు',
	'General_Settings' => 'అమరికలు',
	'General_GiveUsYourFeedback' => 'మీ సూచనలనూ సలహాలనూ తెలియజేయండి!',
	'General_Required' => '%s తప్పనిసరి',
	'General_NotValid' => '%s సరైనది కాదు',
	'General_Error' => 'పొరపాటు',
	'General_Warning' => 'హెచ్చరిక',
	'General_BackToHomepage' => 'తిరిగి పివిక్ ముంగిలికి',
	'General_Yes' => 'అవును',
	'General_No' => 'కాదు',
	'General_Delete' => 'తొలగించు',
	'General_Report' => 'నివేదించు',
	'General_Reports' => 'నివేదికలు',
	'General_Edit' => 'మార్చు',
	'General_Download' => 'దింపుకోలు',
	'General_Ok' => 'సరే',
	'General_Close' => 'మూసివేయి',
	'General_Cancel' => 'రద్దుచేయి',
	'General_Logout' => 'నిష్క్రమించు',
	'General_Username' => 'వాడుకరిపేరు',
	'General_Description' => 'వివరణ',
	'General_Done' => 'పూర్తయ్యింది',
	'General_Name' => 'పేరు',
	'General_Value' => 'విలువ',
	'General_Details' => 'వివరాలు',
	'General_Default' => 'అప్రమేయం',
	'General_NumberOfVisits' => 'సందర్శనల సంఖ్య',
	'General_Date' => 'తేదీ',
	'General_Period' => 'కాలవ్యవధి',
	'General_Today' => 'ఈరోజు',
	'General_Yesterday' => 'నిన్న',
	'General_CurrentWeek' => 'ఈ వారం',
	'General_CurrentMonth' => 'ఈ నెల',
	'General_CurrentYear' => 'ఈ సంవత్సరం',
	'General_DateRange' => 'తేదీ అవధి:',
	'General_LoadingData' => 'భోగట్టా లోడవుతూంది...',
	'General_Loading_js' => 'లోడవుతూంది...',
	'General_GoTo' => '%sకి వెళ్ళండి',
	'General_Next' => 'తదుపరి',
	'General_Previous' => 'గత',
	'General_Search' => 'అన్వేషణ',
	'General_Others' => 'ఇతరాలు',
	'General_Table' => 'పట్టిక',
	'General_TagCloud' => 'ట్యాగు మేఘం',
	'General_Visitors' => 'సందర్శకులు',
	'General_ColumnNbVisits' => 'సందర్శనలు',
	'General_ColumnPercentageVisits' => '% సందర్శనలు',
	'General_ColumnNbActions' => 'చర్యలు',
	'General_ColumnLabel' => 'నామాంకం',
	'General_ColumnConversionRate' => 'మార్పిడి రేటు',
	'General_ColumnActionsPerVisit' => 'సందర్శనకి చర్యలు',
	'General_ColumnExitRate' => 'నిష్క్రమణ రేటు',
	'General_ColumnPageviews' => 'పేజీవీక్షణలు',
	'General_ColumnEntrances' => 'ప్రవేశాలు',
	'General_ColumnExits' => 'నిష్క్రమణలు',
	'General_ColumnValuePerVisit' => 'సందర్శనకి విలువ',
	'General_ColumnVisitsWithConversions' => 'మార్పిళ్ళతో ఉన్న సందర్శనలు',
	'General_YearsDays' => '%1$s సంవత్సరాలు %2$s రోజులు',
	'General_DaysHours' => '%1$s రోజులు %2$s గంటలు',
	'General_HoursMinutes' => '%1$s గంటలు %2$s నిమి',
	'General_MinutesSeconds' => '%1$s నిమి %2$sక్ష',
	'General_Seconds' => '%sక్ష',
	'General_Save' => 'భద్రపరచు',
	'General_ForExampleShort' => 'ఉదా.',
	'General_YouMustBeLoggedIn' => 'ఈ సౌలభ్యాన్ని ఉపయోగించుకోడానికి మీరు ప్రవేశించివుండాలి.',
	'General_Website' => 'వెబ్‌సైటు',
	'General_GeneralSettings' => 'సాధారణ అమరికలు',
	'General_NSeconds' => '%s క్షణాలు',
	'General_NoDataForGraph' => 'ఈ గ్రాఫుకి భోగట్టా లేదు.',
	'General_NewUpdatePiwikX' => 'నవీకరణ: పివిక్ %s',
	'General_AboutPiwikX' => 'పివిక్ %s గురించి',
	'General_BackToPiwik' => 'తిరిగి పివిక్‌కి',
	'General_ShortMonth_1' => 'జన',
	'General_ShortMonth_2' => 'ఫిబ్ర',
	'General_ShortMonth_3' => 'మార్చి',
	'General_ShortMonth_4' => 'ఏప్రి',
	'General_ShortMonth_5' => 'మే',
	'General_ShortMonth_6' => 'జూన్',
	'General_ShortMonth_7' => 'జూలై',
	'General_ShortMonth_8' => 'ఆగ',
	'General_ShortMonth_9' => 'సెప్టె',
	'General_ShortMonth_10' => 'అక్టో',
	'General_ShortMonth_11' => 'నవం',
	'General_ShortMonth_12' => 'డిసెం',
	'General_LongMonth_1' => 'జనవరి',
	'General_LongMonth_2' => 'ఫిబ్రవరి',
	'General_LongMonth_3' => 'మార్చి',
	'General_LongMonth_4' => 'ఏప్రిల్',
	'General_LongMonth_5' => 'మే',
	'General_LongMonth_6' => 'జూన్',
	'General_LongMonth_7' => 'జూలై',
	'General_LongMonth_8' => 'ఆగస్ట్',
	'General_LongMonth_9' => 'సెప్టెంబర్',
	'General_LongMonth_10' => 'అక్టోబర్',
	'General_LongMonth_11' => 'నవంబర్',
	'General_LongMonth_12' => 'డిసెంబర్',
	'General_ShortDay_1' => 'సోమ',
	'General_ShortDay_2' => 'మంగళ',
	'General_ShortDay_3' => 'బుధ',
	'General_ShortDay_4' => 'గురు',
	'General_ShortDay_5' => 'శుక్ర',
	'General_ShortDay_6' => 'శని',
	'General_ShortDay_7' => 'ఆది',
	'General_LongDay_1' => 'సోమవారం',
	'General_LongDay_2' => 'మంగళవారం',
	'General_LongDay_3' => 'బుధవారం',
	'General_LongDay_4' => 'గురువారం',
	'General_LongDay_5' => 'శుక్రవారం',
	'General_LongDay_6' => 'శనివారం',
	'General_LongDay_7' => 'ఆదివారం',
	'General_Daily' => 'రోజూ',
	'General_ChooseLanguage' => 'భాషని ఎంచుకోండి',
	'General_ChoosePeriod' => 'కాలవ్యవధిని ఎంచుకోండి',
	'General_ChooseWebsite' => 'వెబ్ సైటుని ఎంచుకోండి',
	'General_Language' => 'భాష',
	'General_PleaseUpdatePiwik' => 'దయచేసి మీ పివిక్‌ని నవీకరించుకోండి',
	'General_Help' => 'సహాయం',
	'General_OneVisit' => '1 సందర్శన',
	'General_OneDay' => '1 రోజు',
	'General_NDays' => '%s రోజులు',
	'General_GeneralInformation' => 'సాధారణ సమాచారం',
	'Actions_Actions' => 'చర్యలు',
	'Actions_SubmenuPages' => 'పుటలు',
	'Actions_SubmenuPagesEntry' => 'ప్రవేశ పుటలు',
	'Actions_SubmenuPagesExit' => 'నిష్క్రమణ పుటలు',
	'Actions_SubmenuPageTitles' => 'పుటల శీర్షికలు',
	'Actions_SubmenuOutlinks' => 'బయటిలంకెలు',
	'Actions_SubmenuDownloads' => 'దింపుకోళ్ళు',
	'Actions_ColumnClicks' => 'నొక్కులు',
	'Actions_ColumnDownloads' => 'దింపుకోళ్ళు',
	'Actions_ColumnPageName' => 'పుట పేరు',
	'Actions_ColumnPageURL' => 'పుట చిరునామా',
	'Actions_ColumnClickedURL' => 'నొక్కిన URL',
	'Actions_ColumnDownloadURL' => 'దింపుకోలు URL',
	'CoreAdminHome_PluginDescription' => 'పివిక్ యొక్క నిర్వహణా కేంద్రం.',
	'CoreAdminHome_MenuGeneralSettings' => 'సాధారణ అమరికలు',
	'CoreAdminHome_Administration' => 'నిర్వహణ',
	'PrivacyManager_TeaserHeadline' => 'గోప్యతా అమరికలు',
	'PrivacyManager_MenuPrivacySettings' => 'గోప్యత',
	'PrivacyManager_DeleteMaxRowsNoLimit' => 'పరిమితి లేదు',
	'CoreHome_PeriodDay' => 'రోజు',
	'CoreHome_PeriodWeek' => 'వారం',
	'CoreHome_PeriodMonth' => 'నెల',
	'CoreHome_PeriodYear' => 'సంవత్సరం',
	'CoreHome_PeriodDays' => 'రోజులు',
	'CoreHome_PeriodWeeks' => 'వారాలు',
	'CoreHome_PeriodMonths' => 'నెలలు',
	'CoreHome_PeriodYears' => 'సంవత్సరాలు',
	'CoreHome_DaySu_js' => 'ఆ',
	'CoreHome_DayMo_js' => 'సో',
	'CoreHome_DayTu_js' => 'మం',
	'CoreHome_DayWe_js' => 'బు',
	'CoreHome_DayTh_js' => 'గు',
	'CoreHome_DayFr_js' => 'శు',
	'CoreHome_DaySa_js' => 'శ',
	'CoreHome_ShortDay_1_js' => 'ఆది',
	'CoreHome_ShortDay_2_js' => 'సోమ',
	'CoreHome_ShortDay_3_js' => 'మంగళ',
	'CoreHome_ShortDay_4_js' => 'బుధ',
	'CoreHome_ShortDay_5_js' => 'గురు',
	'CoreHome_ShortDay_6_js' => 'శుక్ర',
	'CoreHome_ShortDay_7_js' => 'శని',
	'CoreHome_LongDay_1_js' => 'ఆదివారం',
	'CoreHome_LongDay_2_js' => 'సోమవారం',
	'CoreHome_LongDay_3_js' => 'మంగళవారం',
	'CoreHome_LongDay_4_js' => 'బుధవారం',
	'CoreHome_LongDay_5_js' => 'గురువారం',
	'CoreHome_LongDay_6_js' => 'శుక్రవారం',
	'CoreHome_LongDay_7_js' => 'శనివారం',
	'CoreHome_ShortMonth_1_js' => 'జన',
	'CoreHome_ShortMonth_2_js' => 'ఫిబ్ర',
	'CoreHome_ShortMonth_3_js' => 'మార్చి',
	'CoreHome_ShortMonth_4_js' => 'ఏప్రి',
	'CoreHome_ShortMonth_5_js' => 'మే',
	'CoreHome_ShortMonth_6_js' => 'జూన్',
	'CoreHome_ShortMonth_7_js' => 'జూలై',
	'CoreHome_ShortMonth_8_js' => 'ఆగ',
	'CoreHome_ShortMonth_9_js' => 'సెప్టెం',
	'CoreHome_ShortMonth_10_js' => 'అక్టో',
	'CoreHome_ShortMonth_11_js' => 'నవం',
	'CoreHome_ShortMonth_12_js' => 'డిసెం',
	'CoreHome_MonthJanuary_js' => 'జనవరి',
	'CoreHome_MonthFebruary_js' => 'ఫిబ్రవరి',
	'CoreHome_MonthMarch_js' => 'మార్చి',
	'CoreHome_MonthApril_js' => 'ఏప్రిల్',
	'CoreHome_MonthMay_js' => 'మే',
	'CoreHome_MonthJune_js' => 'జూన్',
	'CoreHome_MonthJuly_js' => 'జూలై',
	'CoreHome_MonthAugust_js' => 'ఆగస్ట్',
	'CoreHome_MonthSeptember_js' => 'సెప్టెంబర్',
	'CoreHome_MonthOctober_js' => 'అక్టోబర్',
	'CoreHome_MonthNovember_js' => 'నవంబర్',
	'CoreHome_MonthDecember_js' => 'డిసెంబర్',
	'CorePluginsAdmin_Plugins' => 'ప్లగిన్లు',
	'CorePluginsAdmin_PluginsManagement' => 'ప్లగిన్ల నిర్వహణ',
	'CorePluginsAdmin_Plugin' => 'ప్లగిన్',
	'CorePluginsAdmin_Version' => 'సంచిక',
	'CorePluginsAdmin_Status' => 'స్థితి',
	'CorePluginsAdmin_Action' => 'చర్య',
	'CorePluginsAdmin_Activated' => 'చేతనమయ్యింది',
	'CorePluginsAdmin_Active' => 'చేతనం',
	'CorePluginsAdmin_Inactive' => 'అచేతనం',
	'CorePluginsAdmin_Deactivate' => 'అచేతనించు',
	'CorePluginsAdmin_Activate' => 'చేతనించు',
	'CorePluginsAdmin_MenuPlugins' => 'ప్లగిన్లు',
	'CoreUpdater_UpdateTitle' => 'నవీకరించు',
	'CoreUpdater_ReadyToGo' => 'వెళ్ళడానికి సిద్ధమా?',
	'CoreUpdater_UpgradePiwik' => 'పివిక్ నవీకరణ',
	'CoreUpdater_UpgradeComplete' => 'నవీకరణ పూర్తయ్యింది!',
	'CoreUpdater_WarningMessages' => 'హెచ్చరిక సందేశాలు:',
	'Dashboard_Dashboard' => 'డాష్‌బోర్డు',
	'Dashboard_WidgetPreview_js' => 'విడ్జెట్ మునుజూపు',
	'Dashboard_Close_js' => 'మూసివేయి',
	'Dashboard_TitleWidgetInDashboard_js' => 'విడ్జెట్ ఇప్పటికే డాష్‌బోర్డులో ఉంది',
	'Dashboard_LoadingWidget_js' => 'విడ్జెట్ లోడవుతూండి, దయచేసి వేచివుండండి...',
	'Goals_Goals' => 'లక్ష్యాలు',
	'Goals_GoalsManagement' => 'లక్ష్యాల నిర్వహణ',
	'Goals_ColumnConversions' => 'మార్పిళ్ళు',
	'Goals_ColumnRevenue' => 'ఆదాయం',
	'Goals_GoalName' => 'లక్ష్యపు పేరు',
	'Goals_Optional' => '(ఐచ్చికం)',
	'Installation_Installation' => 'స్థాపన',
	'Installation_InstallationStatus' => 'స్థాపన స్థితి',
	'Installation_PercentDone' => '%s %% పూర్తి',
	'Installation_DatabaseSetupLogin' => 'వాడుకరిపేరు',
	'Installation_DatabaseSetupPassword' => 'సంకేతపదం',
	'Installation_Congratulations' => 'అభినందనలు',
	'Installation_Password' => 'సంకేతపదం',
	'Installation_PasswordRepeat' => 'సంకేతపదం (మళ్ళీ)',
	'Installation_Email' => 'ఈమెయిలు',
	'Installation_Requirements' => 'పివిక్ ఆవశ్యకాలు',
	'Installation_Optional' => 'ఐచ్చికం',
	'Installation_Welcome' => 'స్వాగతం!',
	'LanguagesManager_AboutPiwikTranslations' => 'పివిక్ అనువాదాల గురించి',
	'Live_Actions' => 'చర్యలు',
	'Live_Action' => 'చర్య',
	'Live_VisitorLog' => 'సందర్శకుల చిట్టా',
	'Live_Time' => 'సమయం',
	'Live_LastMinutes' => 'గత %s నిమిషాలు',
	'Live_LastHours' => 'గత %s గంటలు',
	'Live_GoalType' => 'రకం',
	'Live_GoalRevenue' => 'ఆదాయం',
	'Live_GoalDetails' => 'వివరాలు',
	'Login_Password' => 'సంకేతపదం',
	'Login_PasswordRepeat' => 'సంకేతపదం (మళ్ళీ)',
	'Login_RememberMe' => 'నన్ను గుర్తుంచుకో',
	'Login_LostYourPassword' => 'మీ సంకేతపదాన్ని మర్చిపోయారా?',
	'Mobile_Accounts' => 'ఖాతాలు',
	'Mobile_DefaultReportDate' => 'నివేదిక తేదీ',
	'Referers_SearchEngines' => 'శోధనయంత్రాలు',
	'Referers_Keywords' => 'కీపదాలు',
	'Referers_DirectEntry' => 'నేరు సందర్శన',
	'Referers_Websites' => 'జాలగూళ్ళు',
	'Referers_Campaigns' => 'ప్రచారాలు',
	'Referers_ColumnSearchEngine' => 'శోధనయంత్రం',
	'Referers_ColumnWebsite' => 'జాలగూడు',
	'Referers_ColumnWebsitePage' => 'జాలగూడు పుట',
	'Referers_ColumnKeyword' => 'కీపదం',
	'Referers_ColumnCampaign' => 'ప్రచారం',
	'Referers_SubmenuWebsites' => 'జాలగూళ్ళు',
	'Referers_SubmenuCampaigns' => 'ప్రచారాలు',
	'Referers_WidgetKeywords' => 'కీపదాల యొక్క జాబితా',
	'Referers_WidgetCampaigns' => 'ప్రచారాల యొక్క జాబితా',
	'Referers_WidgetExternalWebsites' => 'బయటి జాలగూళ్ళ యొక్క జాబితా',
	'Referers_WidgetSearchEngines' => 'ఉత్తమ శోధన యంత్రాలు',
	'SEO_AlexaRank' => 'అలెక్సా ర్యాంకు',
	'SEO_Rank' => 'ర్యాంకు',
	'SEO_Pages' => 'పుటలు',
	'SitesManager_Timezone' => 'కాల మండలం',
	'SitesManager_GlobalWebsitesSettings' => 'సార్వత్రిక వెబ్‌సైటు అమరికలు',
	'SitesManager_Currency' => 'మారక ద్రవ్యం',
	'TranslationsAdmin_PluginDescription' => 'పివిక్‌ని మీ భాష లోనికి అనువదించడానికి తోడ్పడండి.',
	'TranslationsAdmin_MenuTranslations' => 'అనువాదాలు',
	'TranslationsAdmin_MenuLanguages' => 'భాషలు',
	'TranslationsAdmin_LanguageCode' => 'భాషా సంకేతం',
	'TranslationsAdmin_Plugin' => 'ప్లగిన్',
	'TranslationsAdmin_Definition' => 'నిర్వచనం',
	'TranslationsAdmin_DefaultString' => 'అసలు పాఠ్యం (ఆంగ్లం)',
	'TranslationsAdmin_TranslationString' => 'అనువాద పాఠ్యం (ప్రస్తుత భాష: %s)',
	'TranslationsAdmin_Translations' => 'అనువాదాలు',
	'TranslationsAdmin_AddLanguage' => 'భాషని చేర్చండి',
	'TranslationsAdmin_Export' => 'భాషని ఎగుమతించు',
	'TranslationsAdmin_Import' => 'భాషని దిగుమతించు',
	'TranslationsAdmin_TranslationAlreadyExists' => 'అనువాదం ఇప్పటికే ఉంది',
	'TranslationsAdmin_InvalidCountry' => 'చెల్లని దేశం',
	'TranslationsAdmin_InvalidLanguage' => 'చెల్లని భాష',
	'UserCountry_Country' => 'దేశం',
	'UserCountry_Continent' => 'ఖండం',
	'UserCountry_City' => 'నగరం',
	'UserCountry_Latitude' => 'అక్షాంశం',
	'UserCountry_Longitude' => 'రేఖాంశం',
	'UserCountry_Location' => 'ప్రాంతం',
	'UserCountry_SubmenuLocations' => 'ప్రాంతాలు',
	'UserCountry_country_ae' => 'యునైటెడ్ అరబ్ ఎమిరేట్స్',
	'UserCountry_country_af' => 'ఆఫ్ఘనిస్తాన్',
	'UserCountry_country_al' => 'అల్బేనియా',
	'UserCountry_country_am' => 'ఆర్మేనియా',
	'UserCountry_country_aq' => 'అంటార్కిటికా',
	'UserCountry_country_ar' => 'అర్జెంటీనా',
	'UserCountry_country_at' => 'ఆస్ట్రియా',
	'UserCountry_country_au' => 'ఆస్ట్రేలియా',
	'UserCountry_country_bb' => 'బార్బడోస్',
	'UserCountry_country_bd' => 'బంగ్లాదేశ్',
	'UserCountry_country_be' => 'బెల్జియం',
	'UserCountry_country_bg' => 'బల్గేరియా',
	'UserCountry_country_bh' => 'బహరైన్',
	'UserCountry_country_bi' => 'బురూండీ',
	'UserCountry_country_bj' => 'బెనిన్',
	'UserCountry_country_bm' => 'బెర్ముడా',
	'UserCountry_country_bo' => 'బొలీవియా',
	'UserCountry_country_br' => 'బ్రెజిల్',
	'UserCountry_country_bs' => 'బహమాస్',
	'UserCountry_country_bt' => 'భూటాన్',
	'UserCountry_country_bu' => 'బర్మా',
	'UserCountry_country_by' => 'బెలారస్',
	'UserCountry_country_ca' => 'కెనడా',
	'UserCountry_country_cg' => 'కాంగో',
	'UserCountry_country_ch' => 'స్విట్జర్లాండ్',
	'UserCountry_country_cl' => 'చీలీ',
	'UserCountry_country_cm' => 'కెమరూన్',
	'UserCountry_country_cn' => 'చైనా',
	'UserCountry_country_co' => 'కొలంబియా',
	'UserCountry_country_cu' => 'క్యూబా',
	'UserCountry_country_cy' => 'సైప్రస్',
	'UserCountry_country_de' => 'జర్మనీ',
	'UserCountry_country_dk' => 'డెన్మార్క్',
	'UserCountry_country_dm' => 'డొమినికా',
	'UserCountry_country_dz' => 'అల్జీరియా',
	'UserCountry_country_eg' => 'ఈజిప్ట్',
	'UserCountry_country_es' => 'స్పెయిన్',
	'UserCountry_country_et' => 'ఇథియోపియా',
	'UserCountry_country_eu' => 'ఐరోపా సమాఖ్య',
	'UserCountry_country_fi' => 'ఫిన్‌లాండ్',
	'UserCountry_country_fj' => 'ఫిజీ',
	'UserCountry_country_fr' => 'ఫ్రాన్స్',
	'UserCountry_country_ge' => 'జార్జియా',
	'UserCountry_country_gf' => 'ఫ్రెంచ్ గయానా',
	'UserCountry_country_gh' => 'ఘనా',
	'UserCountry_country_gi' => 'జిబ్రాల్టర్',
	'UserCountry_country_gl' => 'గ్రీన్‌లాండ్',
	'UserCountry_country_gm' => 'గాంబియా',
	'UserCountry_country_gn' => 'గినియా',
	'UserCountry_country_gr' => 'గ్రీస్',
	'UserCountry_country_gy' => 'గయానా',
	'UserCountry_country_hk' => 'హాంకాంగ్',
	'UserCountry_country_hr' => 'క్రొయేషియా',
	'UserCountry_country_ht' => 'హైతీ',
	'UserCountry_country_hu' => 'హంగరీ',
	'UserCountry_country_id' => 'ఇండోనేషియా',
	'UserCountry_country_ie' => 'ఐర్లాండ్',
	'UserCountry_country_il' => 'ఇజ్రాయేల్',
	'UserCountry_country_in' => 'భారతదేశం',
	'UserCountry_country_iq' => 'ఇరాక్',
	'UserCountry_country_ir' => 'ఇరాన్',
	'UserCountry_country_it' => 'ఇటలీ',
	'UserCountry_country_jm' => 'జమైకా',
	'UserCountry_country_jo' => 'జోర్డాన్',
	'UserCountry_country_jp' => 'జపాన్',
	'UserCountry_country_ke' => 'కెన్యా',
	'UserCountry_country_kh' => 'కాంబోడియా',
	'UserCountry_country_kp' => 'కొరియా ప్రజాస్వామ్య గణతంత్రం',
	'UserCountry_country_kr' => 'కొరియా గణతంత్రం',
	'UserCountry_country_kw' => 'కువైట్',
	'UserCountry_country_kz' => 'కజకిస్తాన్',
	'UserCountry_country_la' => 'లావోస్',
	'UserCountry_country_lb' => 'లెబనాన్',
	'UserCountry_country_lk' => 'శ్రీలంక',
	'UserCountry_country_lr' => 'లైబీరియా',
	'UserCountry_country_lt' => 'లిథుయేనియా',
	'UserCountry_country_lv' => 'లాత్వియా',
	'UserCountry_country_ly' => 'లిబియా',
	'UserCountry_country_ma' => 'మొరాకో',
	'UserCountry_country_mc' => 'మొనాకో',
	'UserCountry_country_mg' => 'మడగాస్కర్',
	'UserCountry_country_mk' => 'మాసిడోనియా',
	'UserCountry_country_mm' => 'మియన్మార్',
	'UserCountry_country_mn' => 'మంగోలియా',
	'UserCountry_country_mt' => 'మాల్టా',
	'UserCountry_country_mu' => 'మారిషస్',
	'UserCountry_country_mv' => 'మాల్దీవులు',
	'UserCountry_country_mx' => 'మెక్సికో',
	'UserCountry_country_my' => 'మలేషియా',
	'UserCountry_country_mz' => 'మొజాంబిక్',
	'UserCountry_country_na' => 'నమీబియా',
	'UserCountry_country_ng' => 'నైజీరియా',
	'UserCountry_country_nl' => 'నెదర్లాండ్స్',
	'UserCountry_country_no' => 'నార్వే',
	'UserCountry_country_np' => 'నేపాల్',
	'UserCountry_country_nz' => 'న్యూజీలాండ్',
	'UserCountry_country_om' => 'ఓమన్',
	'UserCountry_country_pa' => 'పనామా',
	'UserCountry_country_pe' => 'పెరూ',
	'UserCountry_country_ph' => 'ఫిలిప్పీన్స్',
	'UserCountry_country_pk' => 'పాకిస్తాన్',
	'UserCountry_country_pl' => 'పోలాండ్',
	'UserCountry_country_pr' => 'పోర్టో రికో',
	'UserCountry_country_pt' => 'పోర్చుగల్',
	'UserCountry_country_py' => 'పరాగ్వే',
	'UserCountry_country_qa' => 'ఖతార్',
	'UserCountry_country_ro' => 'రొమేనియా',
	'UserCountry_country_rs' => 'సెర్బియా',
	'UserCountry_country_ru' => 'రష్యా',
	'UserCountry_country_rw' => 'రువాండా',
	'UserCountry_country_sa' => 'సౌదీ అరేబియా',
	'UserCountry_country_sc' => 'సీషెల్స్',
	'UserCountry_country_sd' => 'సూడాన్',
	'UserCountry_country_se' => 'స్వీడన్',
	'UserCountry_country_sf' => 'ఫిన్లాండ్',
	'UserCountry_country_sg' => 'సింగపూర్',
	'UserCountry_country_si' => 'స్లొవేనియా',
	'UserCountry_country_sk' => 'స్లొవేకియా',
	'UserCountry_country_sn' => 'సెనెగల్',
	'UserCountry_country_so' => 'సొమాలియా',
	'UserCountry_country_sz' => 'స్వాజిలాండ్',
	'UserCountry_country_tg' => 'టోగో',
	'UserCountry_country_th' => 'థాయిలాండ్',
	'UserCountry_country_tj' => 'తజకిస్తాన్',
	'UserCountry_country_tm' => 'టుర్కుమెనిస్తాన్',
	'UserCountry_country_tp' => 'తూర్పు తైమూర్',
	'UserCountry_country_tr' => 'టర్కీ',
	'UserCountry_country_tw' => 'తైవాన్',
	'UserCountry_country_ua' => 'ఉక్రెయిన్',
	'UserCountry_country_ug' => 'ఉగాండా',
	'UserCountry_country_us' => 'అమెరికా సంయుక్త రాష్ట్రాలు',
	'UserCountry_country_uy' => 'ఉరూగ్వే',
	'UserCountry_country_uz' => 'ఉజ్బెకిస్తాన్',
	'UserCountry_country_va' => 'వాటికన్ నగరం',
	'UserCountry_country_ve' => 'వెనుజులా',
	'UserCountry_country_vn' => 'వియెత్నాం',
	'UserCountry_country_ye' => 'యెమెన్',
	'UserCountry_country_yu' => 'యుగోస్లేవియా',
	'UserCountry_country_za' => 'దక్షిణ ఆఫ్రికా',
	'UserCountry_country_zm' => 'జాంబియా',
	'UserCountry_country_zw' => 'జింబాబ్వే',
	'UserCountry_continent_eur' => 'ఐరోపా',
	'UserCountry_continent_afr' => 'ఆఫ్రికా',
	'UserCountry_continent_asi' => 'ఆసియా',
	'UserCountry_continent_amn' => 'ఉత్తర అమెరికా',
	'UserCountry_continent_amc' => 'మధ్య అమెరికా',
	'UserCountry_continent_ams' => 'దక్షిణ మరియు మధ్య అమెరికా',
	'UserCountryMap_map' => 'పటం',
	'UserCountryMap_worldMap' => 'ప్రపంచ పటం',
	'UserCountryMap_toggleFullscreen' => 'నిండుతెర',
	'UserSettings_VisitorSettings' => 'సందర్శకుల అమరికలు',
	'UserSettings_Browsers' => 'విహారిణులు',
	'UserSettings_Plugins' => 'ప్లగిన్లు',
	'UserSettings_Configurations' => 'స్వరూపణలు',
	'UserSettings_OperatingSystems' => 'నిర్వాహక వ్యవస్థలు',
	'UserSettings_ColumnBrowser' => 'విహారిణి',
	'UserSettings_ColumnPlugin' => 'ప్లగిన్',
	'UserSettings_ColumnConfiguration' => 'స్వరూపణం',
	'UserSettings_ColumnOperatingSystem' => 'నిర్వాహక వ్యవస్థ',
	'UserSettings_ColumnTypeOfScreen' => 'తెర యొక్క రకం',
	'UserSettings_WidgetBrowsers' => 'సందర్శకుల విహారిణులు',
	'UserSettings_WidgetBrowserFamilies' => 'విహారిణి కుటుంబం',
	'UserSettings_WidgetOperatingSystems' => 'నిర్వాహక వ్యవస్థలు',
	'UserSettings_SubmenuSettings' => 'అమరికలు',
	'UsersManager_UsersManagement' => 'వాడుకరుల నిర్వహణ',
	'UsersManager_Sites' => 'వెబ్‌సైట్లు',
	'UsersManager_AllWebsites' => 'అన్ని వెబ్‌సైట్లూ',
	'UsersManager_User' => 'వాడుకరి',
	'UsersManager_Password' => 'సంకేతపదం',
	'UsersManager_Email' => 'ఈమెయిలు',
	'UsersManager_Alias' => 'మారుపేరు',
	'UsersManager_Edit' => 'మార్చు',
	'UsersManager_AddUser' => 'ఒక కొత్త వాడుకరిని చేర్చు',
	'UsersManager_MenuUsers' => 'వాడుకరులు',
	'UsersManager_MenuUserSettings' => 'వాడుకరి అమరికలు',
	'UsersManager_MenuAnonymousUserSettings' => 'ఆజ్ఞాత వాడుకరుల అమరికలు',
	'UsersManager_ExceptionLoginExists' => '\'%s\' వాడుకరి ఇప్పటికే ఉన్నారు.',
	'VisitFrequency_ColumnReturningVisits' => 'పునః సందర్శనలు',
	'VisitFrequency_SubmenuFrequency' => 'తరచుదనం',
	'VisitorGenerator_Submit' => 'దాఖలుచేయి',
	'VisitorInterest_PluginDescription' => 'సందర్శకుల ఆసక్తి గురించిన నివేదికలు: చూసిన పుటల సంఖ్య, సైటులో గడిపిన సమయం.',
	'VisitorInterest_VisitsPerDuration' => 'నిడివి ప్రకారం సందర్శనలు',
	'VisitorInterest_VisitsPerNbOfPages' => 'పుటల సంఖ్య ప్రకారం సందర్శనలు',
	'VisitorInterest_ColumnVisitDuration' => 'సందర్శన నిడివి',
	'VisitorInterest_ColumnPagesPerVisit' => 'సందర్శనలో పుటలు',
	'VisitorInterest_WidgetLengths' => 'సందర్శనల పొడవు',
	'VisitorInterest_WidgetPages' => 'సందర్శనలో పుటలు',
	'VisitorInterest_PlusXMin' => '%s నిమి',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s నిమి',
	'VisitorInterest_OnePage' => '1 పుట',
	'VisitorInterest_NPages' => '%s పుటలు',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$sక్ష',
	'VisitsSummary_VisitsSummary' => 'సందర్శనల సంగ్రహం',
	'VisitTime_ColumnLocalTime' => 'స్థానిక సమయం',
	'PDFReports_PiwikReports' => 'పివిక్ నివేదికలు',

	// FOR REVIEW
	'Forecast_Visitors' => 'సందర్శకులు',
	'GeoIP_ColumnCity' => 'నగరం',
	'GeoIP_Continent' => 'ఖండం',
	'GeoIP_Country' => 'దేశం',
	'UserLanguage_Language' => 'భాషలు',
	'UserLanguage_Language_bn' => 'బెంగాలీ',
	'UserLanguage_Language_en' => 'ఆంగ్లం',
	'UserLanguage_Language_hi' => 'హిందీ',
	'UserLanguage_Language_ja' => 'జపనీ',
	'UserLanguage_Language_la' => 'లాటిన్',
	'UserLanguage_Language_or' => 'ఒరియా',
	'UserLanguage_SubmenuLanguage' => 'భాషలు',
	'UserLanguage_WidgetLanguage' => 'సందర్శకుల భాషలు',
);
